@@ -6,13 +6,13 @@ Puppet::Type.type(:vcsrepo).provide(:dummy, parent: Puppet::Provider::Vcsrepo) d
   desc 'Dummy default provider'
 
   defaultfor feature: :posix
-  defaultfor operatingsystem: :windows
+  defaultfor 'os.name': :windows
 
   def working_copy_exists?
     providers = begin
       @resource.class.providers.map(&:to_s).sort.reject { |x| x == 'dummy' }.join(', ')
-    rescue StandardError
-      'none'
+                rescue StandardError
+                  'none'
     end
     raise("vcsrepo resource must have a provider, available: #{providers}")
   end
